# Chunk 1 - load functions and set up folder structure

list.of.packages <- c("data.table","bit64","R2HTML","caret","randomForest","shiny")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)

library(shiny)
library(data.table)
library(bit64)
library(caret)
library(randomForest)
library(R2HTML)






#Chunk 2 - Load data and functions
load(file.path('RData','Phase_1_Features.RData'))
set.seed(25)
officialIDs=fread(file.path('input','officialIDs.csv'),integer64='numeric',data.table=FALSE)$V1 
posLabels=officialIDs[officialIDs %in% features$userID] 
negLabels=sample(features$userID[features$followerCount<100000],length(posLabels))
officialTrainTest=TrainTest_SetBuilder(data=features,PositiveLabels=posLabels,NegativeLabels=negLabels,p.test.split=.4)  

r=.5 # lower r emphasized precision over recall
classifier(data_list=officialTrainTest,
           algorithm='randomForest',
           evaluation=TRUE,
           metric='Kappa',
           ratio=r, 
           t='official')

# Chunk 3 - Apply Classifier and Remove Accounts
set.seed(25)
official.predicted =classifier(data_list=officialTrainTest,
                               algorithm='randomForest',
                               evaluation=FALSE,
                               metric='Kappa',
                               ratio=r, # *** important parameter
                               t='official')

officialIDs=c(official.predicted,posLabels)
features=features[!(features$userID %in% officialIDs),]
save(features,file=file.path('RData','Phase_2_Features.RData'))
rm('negLabels','official.predicted','officialIDs','officialTrainTest','posLabels','r','list.of.packages','new.packages')


#Chunk 4 - develop positive case labels
load(file.path('RData','dense_communities.RData'))
posLabels=denseOutput$userID[denseOutput$denseCluster=='d-14']
set.seed(25)
negLabels=sample(features$userID,length(posLabels))
negLabels=negLabels[!(negLabels %in% posLabels)]

#Chunk 5 - develop Euromaidan Classifier
set.seed(25)
euromaidanTrainTest=TrainTest_SetBuilder(data=features,PositiveLabels=posLabels,NegativeLabels=negLabels,p.test.split=.4)  
r=.5 # lower r emphasized precision over recall
classifier(data_list=euromaidanTrainTest,
           algorithm='randomForest',
           evaluation=TRUE,
           metric='Kappa',
           ratio=r, # *** important parameter 
           t='euromaidan')

# Chunk 6 - Apply Classifier and Remove Accounts
set.seed(25)
euromaidan.predicted =classifier(data_list=euromaidanTrainTest,
                               algorithm='randomForest',
                               evaluation=FALSE,
                               metric='Kappa',
                               ratio=r, # *** important parameter
                               t='euromaidan')

euromaidanIDs=c(euromaidan.predicted,posLabels)
features=features[features$userID %in% euromaidanIDs,]
df=denseOutput[,c('userID','denseCluster')]
finalOutput=merge(df,features,by='userID',all.y=TRUE,sort=FALSE)
finalOutput$ScreenName=hyperlink(finalOutput$ScreenName)
save(finalOutput,file=file.path('RData','euromaidan_community.RData'))





